"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var mocks_1 = require("../mocks/mocks");
var getIosStatusAddressToolBarOffsets_1 = require("./getIosStatusAddressToolBarOffsets");
var constants_1 = require("../helpers/constants");
describe('getIosStatusAddressToolBarOffsets', function () {
    it('should get the correct status, address and toolbar height for a default iPhone with iOS 14 in Portrait mode', function () {
        setEnvironment('IOS', 14, 'IPHONE', false);
        expect((0, getIosStatusAddressToolBarOffsets_1.default)(constants_1.IOS_OFFSETS)).toMatchSnapshot();
    });
    it('should get the correct status, address and toolbar height for a default iPhone with iOS 14 in landscape mode', function () {
        setEnvironment('IOS', 14, 'IPHONE', true);
        expect((0, getIosStatusAddressToolBarOffsets_1.default)(constants_1.IOS_OFFSETS)).toMatchSnapshot();
    });
    it('should get the correct status, address and toolbar height for a default iPhone with iOS 15 in portrait mode', function () {
        setEnvironment('IOS', 15, 'IPHONE_X', false);
        expect((0, getIosStatusAddressToolBarOffsets_1.default)(constants_1.IOS_OFFSETS)).toMatchSnapshot();
    });
    it('should get the correct status, address and toolbar height for a default iPhone with iOS 15 in landscape mode', function () {
        setEnvironment('IOS', 15, 'IPHONE_X', true);
        expect((0, getIosStatusAddressToolBarOffsets_1.default)(constants_1.IOS_OFFSETS)).toMatchSnapshot();
    });
    it('should get the correct status, address and toolbar height for an iPhone with extreme not known dimensions', function () {
        setEnvironment('IOS', 15, 'IPHONE_HEIGHT', false);
        expect((0, getIosStatusAddressToolBarOffsets_1.default)(constants_1.IOS_OFFSETS)).toMatchSnapshot();
    });
    it('should get the correct status, address and toolbar height for an iPad', function () {
        setEnvironment('IOS', 15, 'IPAD', false);
        expect((0, getIosStatusAddressToolBarOffsets_1.default)(constants_1.IOS_OFFSETS)).toMatchSnapshot();
    });
    it('should get the correct status, address and toolbar height for an iPad with big sizes', function () {
        setEnvironment('IOS', 15, 'IPAD_BIG_SIZE', false);
        expect((0, getIosStatusAddressToolBarOffsets_1.default)(constants_1.IOS_OFFSETS)).toMatchSnapshot();
    });
});
function setEnvironment(os, version, phone, isLandscape) {
    Object.defineProperty(navigator, 'appVersion', __assign({ value: mocks_1.NAVIGATOR_APP_VERSIONS[os][version] }, mocks_1.CONFIGURABLE));
    Object.defineProperty(window.screen, 'width', __assign({ value: mocks_1.IOS_DEVICES[phone].width }, mocks_1.CONFIGURABLE));
    Object.defineProperty(window.screen, 'height', __assign({ value: mocks_1.IOS_DEVICES[phone].height }, mocks_1.CONFIGURABLE));
    Object.defineProperty(window, 'innerWidth', __assign({ value: mocks_1.IOS_DEVICES[phone].innerWidth }, mocks_1.CONFIGURABLE));
    Object.defineProperty(window, 'innerHeight', __assign({ value: mocks_1.IOS_DEVICES[phone].innerHeight }, mocks_1.CONFIGURABLE));
    Object.defineProperty(window, 'matchMedia', __assign({ value: jest.fn().mockImplementation(function () { return ({
            matches: isLandscape,
        }); }) }, mocks_1.CONFIGURABLE));
}
//# sourceMappingURL=getIosStatusAddressToolBarOffsets.spec.js.map